@@ -137,7 +137,6 @@ proc Widget::tkinclude { class tkwidget subpath args } {
     upvar 0 ${class}::map$subpath submap
     upvar 0 ${class}::optionExports exports
 
-    set foo [$tkwidget ".ericFoo###"]
     # create resources informations from tk widget resources
     foreach optdesc [_get_tkwidget_options $tkwidget] {
         set option [lindex $optdesc 0]
@@ -189,7 +188,6 @@ proc Widget::tkinclude { class tkwidget subpath args } {
             }
         }
     }
-    ::destroy $foo
 }
 
 
@@ -374,24 +372,24 @@ proc Widget::declare { class optlist } {
         # retreive default value for TkResource
         if { [string equal $type "TkResource"] } {
             set tkwidget [lindex $arg 0]
-	    set foo [$tkwidget ".ericFoo##"]
             set realopt  [lindex $arg 1]
             if { ![string length $realopt] } {
                 set realopt $option
             }
             set tkoptions [_get_tkwidget_options $tkwidget]
+            set ind [lsearch $tkoptions [list $realopt *]]
+            set optdesc [lindex $tkoptions $ind];
+            set tkoptions [_get_tkwidget_options $tkwidget]
             if { ![string length $value] } {
                 # We initialize default value
-		set ind [lsearch $tkoptions [list $realopt *]]
-                set value [lindex [lindex $tkoptions $ind] end]
+                set value [lindex $optdesc end]
             }
 	    set optionDbName ".[lindex [_configure_option $option ""] 0]"
 	    option add *${class}${optionDbName} $value widgetDefault
 	    set exports($option) $optionDbName
             set classopt($option) [list TkResource $value $ro \
 		    [list $tkwidget $realopt]]
-	    set optionClass($option) [lindex [$foo configure $realopt] 1]
-	    ::destroy $foo
+	    set optionClass($option) [lindex $optdesc 1]
             continue
         }
 
@@ -437,7 +435,6 @@ proc Widget::create { class path {rename 1} } {
 proc Widget::addmap { class subclass subpath options } {
     upvar 0 ${class}::opt classopt
     upvar 0 ${class}::optionExports exports
-    upvar 0 ${class}::optionClass optionClass
     upvar 0 ${class}::map classmap
     upvar 0 ${class}::map$subpath submap
 
@@ -460,21 +457,6 @@ proc Widget::addmap { class subclass subpath options } {
 }
 
 
-# ----------------------------------------------------------------------------
-#  Command Widget::syncoptions
-# ----------------------------------------------------------------------------
-proc Widget::syncoptions { class subclass subpath options } {
-    upvar 0 ${class}::sync classync
-
-    foreach {option realopt} $options {
-        if { ![string length $realopt] } {
-            set realopt $option
-        }
-        set classync($option) [list $subpath $subclass $realopt]
-    }
-}
-
-
 # ----------------------------------------------------------------------------
 #  Command Widget::init
 # ----------------------------------------------------------------------------
@@ -1100,6 +1082,19 @@ proc Widget::_configure_option { option altopt } {
     return [list $optdb $optclass]
 }
 
+# ----------------------------------------------------------------------------
+#  Command Widget::_make_tk_widget_name
+# ----------------------------------------------------------------------------
+# Before, the widget meta name was build as: ".#BWidget.#$tkwidget"
+# This does not work for ttk widgets, as they have an "::" in their name.
+# Thus replace any "::" by "__" will do the job.
+proc Widget::_make_tk_widget_name { tkwidget } {
+    set pos 0
+    for {set pos 0} {0 <= [set pos [string first "::" $tkwidget $pos]]} {incr pos} {
+	set tkwidget [string range $tkwidget 0 [expr {$pos-1}]]__[string range $tkwidget [expr {$pos+2}] end]
+    }
+    return ".#BWidget.#$tkwidget"
+}
 
 # ----------------------------------------------------------------------------
 #  Command Widget::_get_tkwidget_options
@@ -1109,7 +1104,7 @@ proc Widget::_get_tkwidget_options { tkwidget } {
     variable _optiondb
     variable _optionclass
 
-    set widget ".#BWidget.#$tkwidget"
+    set widget [_make_tk_widget_name $tkwidget]
     # encapsulation frame to not pollute '.' childspace
     if {![winfo exists ".#BWidget"]} { frame ".#BWidget" }
     if { ![winfo exists $widget] || ![info exists _tk_widget($tkwidget)] } {
@@ -1162,7 +1157,7 @@ proc Widget::_test_tkresource { option value arg } {
 #    set tkwidget [lindex $arg 0]
 #    set realopt  [lindex $arg 1]
     foreach {tkwidget realopt} $arg break
-    set path     ".#BWidget.#$tkwidget"
+    set path     [_make_tk_widget_name $tkwidget]
     set old      [$path cget $realopt]
     $path configure $realopt $value
     set res      [$path cget $realopt]
@@ -1475,12 +1470,68 @@ proc Widget::traverseTo { w } {
     event generate $w <<TraverseIn>>
 }
 
+# Widget::which --
+#
+#	Retrieve a fully qualified variable name for the specified option or
+#	widget variable.
+#
+#	If the option is not one for which a variable exists, throw an error
+#	(ie, those options that map directly to widget options).
+#
+#	For widget variables, return the fully qualified name even if the
+#	variable had not been previously set, in order to allow adding variable
+#	traces prior to their creation.
+#
+# Arguments:
+#	path	megawidget to get an option var for.
+#	type	either -option or -variable.
+#	name    name of the option or widget variable.
+#
+# Results:
+#	Fully qualified name of the variable for the option or the widget
+#	variable.
+#
+proc Widget::which {path args} {
+    switch -- [llength $args] {
+	1 {
+	    set type -option;
+	    set name [lindex $args 0];
+	}
+	2 {
+	    set type [lindex $args 0];
+	    set name [lindex $args 1];
+	}
+	default {
+	    return -code error "incorrect number of arguments";
+	}
+    }
+
+    variable _class;
+    set class $_class($path);
+
+    switch -- $type {
+	-option {
+	    upvar 0 ${class}::$path:opt pathopt;
+
+	    if { ![info exists pathopt($name)] } {
+		error "unable to find variable for option \"$name\"";
+	    }
+
+	    return ::Widget::${class}::${path}:opt(${name});
+	}
+	-variable {
+	    return ${class}::${path}:${name};
+	}
+    }
+}
+
 
 # Widget::varForOption --
 #
 #	Retrieve a fully qualified variable name for the option specified.
 #	If the option is not one for which a variable exists, throw an error 
-#	(ie, those options that map directly to widget options).
+#	(ie, those options that map directly to widget options) Superseded by
+#       widget::which.
 #
 # Arguments:
 #	path	megawidget to get an option var for.
@@ -1490,17 +1541,7 @@ proc Widget::traverseTo { w } {
 #	varname	name of the variable, fully qualified, suitable for tracing.
 
 proc Widget::varForOption {path option} {
-    variable _class
-    variable _optiontype
-
-    set class $_class($path)
-    upvar 0 ${class}::$path:opt pathopt
-
-    if { ![info exists pathopt($option)] } {
-	error "unable to find variable for option \"$option\""
-    }
-    set varname "::Widget::${class}::$path:opt($option)"
-    return $varname
+    return [::Widget::which $path -option $option];
 }
 
 # Widget::getVariable --
@@ -1518,7 +1559,7 @@ proc Widget::getVariable { path varName {newVarName ""} } {
     variable _class
     set class $_class($path)
     if {![string length $newVarName]} { set newVarName $varName }
-    uplevel 1 [list upvar \#0 ${class}::$path:$varName $newVarName]
+    uplevel 1 [list ::upvar \#0 ${class}::$path:$varName $newVarName]
 }
 
 # Widget::options --
